# -*- coding: utf-8 -*-
###############################################################################
#
#   invoice_payment_method for OpenERP
#   Copyright (C) 2013-TODAY Akretion <http://www.akretion.com>.
#   @author Sébastien BEAU <sebastien.beau@akretion.com>
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################

from openerp.osv import osv, fields


class account_move_line(osv.Model):
    _inherit = "account.move.line"

    _columns = {
        'payment_method_id': fields.many2one('payment.method',
                                             'Payment Method',
                                             ondelete='restrict'),
    }

    def _auto_init(self, cr, context=None):
        super(account_move_line, self)._auto_init(cr, context=context) 
        cr.execute("SELECT state from ir_module_module where name = 'invoice_payment_method'")
        state = cr.fetchone()[0]
        if state == "to install":
           cr.execute(
            """UPDATE account_move_line set payment_method_id = so.payment_method_id
                    FROM account_invoice as inv
                    FULL JOIN sale_order_invoice_rel as rel ON rel.invoice_id = inv.id
                    FULL JOIN sale_order AS so ON rel.order_id = so.id
                    WHERE inv.move_id = account_move_line.move_id
                         and inv.account_id = account_move_line.account_id;
            """)


class account_invoice(osv.Model):
    _inherit = "account.invoice"

    def action_move_create(self, cr, uid, ids, context=None):
        if context is None:
            context = {}
        for inv_id in ids:
            ctx = context.copy()
            ctx['create_from_inv_id'] = inv_id
            super(account_invoice, self).action_move_create(cr, uid, [inv_id], context=ctx)
        return True


class account_move(osv.Model):
    _inherit = "account.move"

    def create(self, cr, uid, vals, context=None):
        if context is None:
            context = {}
        if context.get('create_from_inv_id'):
            inv_obj = self.pool['account.invoice']
            inv = inv_obj.browse(cr, uid, context['create_from_inv_id'], context=context)
            for line in vals['line_id']:
                if line[2]['account_id'] == inv.account_id.id:
                    line[2]['payment_method_id'] = inv.payment_method_id.id
        return super(account_move, self).create(cr, uid, vals, context=context)
