# -*- coding: utf-8 -*-
###############################################################################
#
#   invoice_payment_method for OpenERP
#   Copyright (C) 2013-TODAY Akretion <http://www.akretion.com>.
#   @author Sébastien BEAU <sebastien.beau@akretion.com>
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as
#   published by the Free Software Foundation, either version 3 of the
#   License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################

from openerp.osv import orm, fields

class sale_order(orm.Model):
    _inherit = "sale.order"

    def _prepare_invoice(self, cr, uid, order, lines, context=None):
        vals = super(sale_order, self)._prepare_invoice(cr, uid, order,
                                                     lines, context=context)
        vals['payment_method_id'] = order.payment_method_id.id
        return vals


class account_invoice(orm.Model):
    _inherit = "account.invoice"

    _columns = {
        'payment_method_id': fields.many2one('payment.method',
                                             'Payment Method',
                                             ondelete='restrict'),
    }

    def _auto_init(self, cr, context=None):
        super(account_invoice, self)._auto_init(cr, context=context) 
        cr.execute("SELECT state from ir_module_module where name = 'invoice_payment_method'")
        state = cr.fetchone()[0]
        if state =="to install":
            cr.execute(
            """UPDATE account_invoice set payment_method_id = so.payment_method_id
                    FROM sale_order_invoice_rel as rel
                    FULL JOIN sale_order AS so ON rel.order_id = so.id
                    WHERE account_invoice.id = rel.invoice_id;
            """)
    
    def onchange_payment_method_id(self, cr, uid, ids, payment_method_id, context=None):
        if context is None:
            context = {}
        res = {'value':{}}
        method_obj = self.pool['payment.method']
        #compatibility for sale_payment_method_sale_journal
        if method_obj._columns.get('sale_account_id'):
            method = method_obj.browse(cr, uid, payment_method_id, context=context)
            if method.sale_account_id:
                res['value']['account_id'] = method.sale_account_id.id
            if method.sale_journal_id:
                res['value']['journal_id'] = method.sale_journal_id.id
        return res

    def _prepare_refund(self, cr, uid, invoice_id, *args, **kwargs):
        result = super(account_invoice, self)._prepare_refund(cr, uid, invoice_id, *args, **kwargs)
        invoice = self.read(cr, uid, invoice_id, ['payment_method_id'], context=kwargs['context'])
        result['payment_method_id'] = invoice['payment_method_id'][0]
        return result